%global gitdate     20130827
%global commit      66b5d74f8417459414cbf3753cfa9a0128483cbd
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Name:           mathic
Version:        1.0
Release:        1.%{gitdate}.git%{shortcommit}%{?dist}
Summary:        Data structures for Groebner basis computations

# See https://github.com/broune/mathic/pull/3 where communication from
# upstream specifying the license is described.
License:        LGPLv2+
URL:            https://github.com/broune/mathic
Source0:        https://github.com/broune/mathic/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
# Fix a test that fails spuriously due to a scoping violation.  Patch has been
# submitted upstream: https://github.com/broune/mathic/pull/3.
Patch0:         %{name}-test.patch

BuildRequires:  gtest-devel
BuildRequires:  libtool
BuildRequires:  memtailor-devel

%description
Mathic is a C++ library of fast data structures designed for use in
Groebner basis computation.  This includes data structures for ordering
S-pairs, performing divisor queries and ordering polynomial terms during
polynomial reduction.

With Mathic you get to use highly optimized code with little effort so
that you can focus more of your time on whatever part of your Groebner
basis implementation that you are interested in.  The data structures
use templates to allow you to use them with whatever representation of
monomials/terms and coefficients that your code uses.  In fact the only
places where Mathic defines its own monomials/terms is in the test code
and example code.  Currently only dense representations of
terms/monomials are suitable since Mathic will frequently ask "what is
the exponent of variable number x in this term/monomial?".

%package devel
Summary:        Development files for mathic
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Files for developing applications that use mathic.

%prep
%setup -q -n %{name}-%{commit}
%patch0

# Every file is marked executable; only a few need to be.
find . -type f -perm /0111 | xargs chmod a-x
chmod a+x autogen.sh fixspace replace

# Fool the configure script into not downloading gtest
sed -e 's,gtest/src/gtest-all\.cc,include/gtest/gtest.h,' \
    -e 's,gtest/include,include/gtest,' \
    -e 's,-I`cd \$GTEST_PATH/gtest/; echo \$PWD`,,' \
    -i configure.ac

# Fool the tests into not compiling with gtest source
sed -i 's,\.\./src/gtest-all\.cc,gtest/gtest.h,' src/test/gtestInclude.cpp

# Link tests with the installed gtest library and update the C++ standard
sed -e 's/gnu++0x/gnu++11/' \
    -e 's/unittest_LDFLAGS.*/& -lgtest/' \
    -i Makefile.am

# Upstream doesn't generate the configure script
./autogen.sh

%build
export GTEST_PATH=%{_prefix}
export GEST_LIBS="-lgtest"
export GTEST_VERSION=$(gtest-config --version)
%configure --disable-static --with-gtest=yes

# Get rid of undesirable hardcoded rpaths; workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i libtool

make %{?_smp_mflags}

%install
%make_install

# We don't want the libtool archive
rm -f %{buildroot}%{_libdir}/lib%{name}.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%check
export LD_LIBRARY_PATH=$PWD/.libs
make check

%files
%doc README.md
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/%{name}.h
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Fri Nov 27 2015 Jerry James <loganjerry@gmail.com> - 1.0-1.20130827.git66b5d74
- Initial RPM
